SystemOrganization addCategory: #'Javascript-Tests-Core'!

TestCase subclass: #JSJsonTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Javascript-Tests-Core'!

!JSJsonTest methodsFor: 'utilities' stamp: 'lr 2/17/2008 17:52'!
parse: aString
	^ JSJsonParser parse: aString startingAt: JSJsonParser startingStateForValue! !

!JSJsonTest methodsFor: 'testing-array' stamp: 'lr 2/17/2008 17:49'!
testBigArray
	| result |
	result := self parse: '[a,b]'.
	self assert: (result isKindOf: OrderedCollection).
	self assert: (result at: 1) = 'a'.
	self assert: (result at: 2) = 'b'.
	self assert: (result size) = 2! !

!JSJsonTest methodsFor: 'testing-objects' stamp: 'lr 2/17/2008 17:49'!
testBigObject
	| result |
	result := self parse: '{a:1,b:2}'.
	self assert: (result isKindOf: Dictionary).
	self assert: (result at: 'a') = 1.
	self assert: (result at: 'b') = 2.
	self assert: (result size) = 2! !

!JSJsonTest methodsFor: 'testing' stamp: 'lr 2/17/2008 18:02'!
testComment
	self assert: (self parse: '// bla
"hallo"') = 'hallo'.
	self assert: (self parse: '"hallo"
// bla') = 'hallo'.
	self assert: (self parse: '"hallo" // bla') = 'hallo'.

	self assert: (self parse: '/* bla */ "hallo"') = 'hallo'.
	self assert: (self parse: '"hallo" /* bla */') = 'hallo'.
	self assert: (self parse: '/* bla */ "hallo" /* bla */') = 'hallo'! !

!JSJsonTest methodsFor: 'testing-array' stamp: 'lr 2/17/2008 17:49'!
testEmptyArray
	| result |
	result := self parse: '[]'.
	self assert: (result isKindOf: OrderedCollection).
	self assert: (result isEmpty)! !

!JSJsonTest methodsFor: 'testing-objects' stamp: 'lr 2/17/2008 17:49'!
testEmptyObject
	| result |
	result := self parse: '{}'.
	self assert: (result isKindOf: Dictionary).
	self assert: (result isEmpty)! !

!JSJsonTest methodsFor: 'testing-literals' stamp: 'lr 2/17/2008 17:49'!
testFalse
	self assert: (self parse: 'false') = false.
	self assert: (self parse: 'False') = 'False'! !

!JSJsonTest methodsFor: 'testing-literals' stamp: 'lr 3/25/2008 22:13'!
testNull
	self assert: (self parse: 'null') isNil.
	self assert: (self parse: 'NULL') = 'NULL'! !

!JSJsonTest methodsFor: 'testing-literals' stamp: 'lr 2/17/2008 17:54'!
testNumber
	self assert: (self parse: '0') = 0.
	self assert: (self parse: '1') = 1.
	self assert: (self parse: '12') = 12.
	self assert: (self parse: '-12') = -12.
	self assert: (self parse: '12.3') = 12.3.
	self assert: (self parse: '0.12') = 0.12.
	self assert: (self parse: '1e10') = 1.0e10.
	self assert: (self parse: '1.1e10') = 1.1e10.
	self assert: (self parse: '1.1e10') = 1.1e10.
	self assert: (self parse: '1.1e10') = 1.1e10.
	self assert: (self parse: '1.1e-10') = 1.1e-10! !

!JSJsonTest methodsFor: 'testing-array' stamp: 'lr 2/17/2008 17:49'!
testSmallArray
	| result |
	result := self parse: '[a]'.
	self assert: (result isKindOf: OrderedCollection).
	self assert: (result at: 1) = 'a'.
	self assert: (result size) = 1! !

!JSJsonTest methodsFor: 'testing-objects' stamp: 'lr 2/17/2008 17:49'!
testSmallObject
	| result |
	result := self parse: '{a:1}'.
	self assert: (result isKindOf: Dictionary).
	self assert: (result at: 'a') = 1.
	self assert: (result size) = 1! !

!JSJsonTest methodsFor: 'testing-literals' stamp: 'lr 2/17/2008 17:55'!
testString
	self assert: (self parse: '""') = ''.
	self assert: (self parse: '"foo"') = 'foo'.
	self assert: (self parse: '"fo\"o"') = 'fo\"o'.
	self assert: (self parse: '''''') = ''.
	self assert: (self parse: '''foo''') = 'foo'.
	self assert: (self parse: '''fo\''o''') = 'fo\''o'! !

!JSJsonTest methodsFor: 'testing-literals' stamp: 'lr 2/17/2008 17:49'!
testTrue
	self assert: (self parse: 'true') = true.
	self assert: (self parse: 'True') = 'True'! !

TestCase subclass: #JSObjectTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Javascript-Tests-Core'!

JSObjectTest subclass: #JSConversionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Javascript-Tests-Core'!

!JSConversionTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:48'!
testArray
	self assert: #(1 2 3) equals: '[1,2,3]'! !

!JSConversionTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:55'!
testAssociation
	self assert: ('a' -> 'b') equals: 'a:"b"'.
	self assert: ('a' -> 1) equals: 'a:1'.
	self assert: ('a' -> nil) equals: 'a:null'.
	
	self assert: ('' -> 1) equals: '"":1'.
	self assert: (' ' -> 2) equals: '" ":2'.
	self assert: ('1a' -> 3) equals: '"1a":3'.
	self assert: ('a ' -> 4) equals: '"a ":4'! !

!JSConversionTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:48'!
testCharacter
	self assert: (Character value: 0) equals: '"\0"'.
	self assert: Character lf equals: '"\n"'.
	self assert: $a equals: '"a"'! !

!JSConversionTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:48'!
testColor
	self assert: Color red equals: '"#FF0000"'! !

!JSConversionTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:48'!
testDateAndTime
	self assert: (DateAndTime year: 1980 month: 6 day: 11 hour: 12 minute: 45 second: 23) equals: 'new Date(1980,5,11,12,45,23)'.
	self assert: (Date year: 1980 month: 6 day: 11) equals: 'new Date(1980,5,11)'! !

!JSConversionTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:48'!
testDictionary
	self
		assert: (WASmallDictionary new 
			at: 'foo' put: 1; 
			at: 'bar' put: 2; 
			at: 'zork' put: 3;
			yourself)
		equals: '{foo:1,bar:2,zork:3}'.
	self
		assert: (WASmallDictionary new at: '' put: 'empty'; yourself)
		equals: '{"":"empty"}'.
	self
		assert: (WASmallDictionary new at: 1 put: 'not-a-string'; yourself)
		equals: '{"1":"not-a-string"}'.
	self
		assert: (WASmallDictionary new at: '1abc' put: 'not-an-id'; yourself)
		equals: '{"1abc":"not-an-id"}'.
	self
		assert: (WASmallDictionary new at: 'abc1' put: 'totally sexy'; yourself)
		equals: '{abc1:"totally sexy"}'! !

!JSConversionTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:57'!
testDuration
	self assert: (Duration seconds: 1) equals: '1000'.
	self assert: (Duration milliSeconds: 1200) equals: '1200'! !

!JSConversionTest methodsFor: 'testing' stamp: 'lr 10/13/2008 22:01'!
testInterval
	self
		assert: (self mock interval: 2 seconds)
		equals: 'setInterval(function(){mock},2000)'! !

!JSConversionTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:48'!
testLiteral
	self assert: true equals: 'true'.
	self assert: false equals: 'false'.
	self assert: nil equals: 'null'! !

!JSConversionTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:48'!
testNumber
	self assert: 123 equals: '123'! !

!JSConversionTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:48'!
testPoint
	self assert: 1 @ 2 equals: '[1,2]'! !

!JSConversionTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:48'!
testStringBasic
	self assert: 'abc' equals: '"abc"'.
	self assert: '123' equals: '"123"'! !

!JSConversionTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:48'!
testStringEscaping
	self assert: '''' equals: '"''"'.
	self assert: '"' equals: '"\""'.
	self assert: '\' equals: '"\\"'! !

!JSConversionTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:48'!
testStringSpecial
	self assert: (String with: Character cr) equals: '"\r"'.
	self assert: (String with: Character lf) equals: '"\n"'.
	self assert: (String with: Character tab) equals: '"\t"'.

	self assert: (String with: (Character value: 0)) equals: '"\0"'.
	self assert: (String with: (Character value: 1)) equals: '"\x01"'.
	self assert: (String with: (Character value: 31)) equals: '"\x1F"'! !

!JSConversionTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:48'!
testStringUnicode
	self assert: (String with: (Character value: 1024)) equals: '"\u0400"'.
	self assert: (String with: (Character value: 8364)) equals: '"\u20AC"'! !

!JSConversionTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:48'!
testUrl
	self
		assert: (WAUrl absolute: 'http://www.seaside.st/?1=a&2=b')
		equals: '"http://www.seaside.st/?1=a&2=b"'! !

JSObjectTest subclass: #JSDecorationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Javascript-Tests-Core'!

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:58'!
testAccess
	self
		assert: (self mock access: 'foo')
		equals: 'mock.foo'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:58'!
testAlias
	| mock |
	mock := self mock.
	mock alias: 'foo'.
	self assert: mock equals: 'foo'.
	mock alias: 'bar'; call: 'zork'.
	self assert: mock equals: 'bar.zork()'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:58'!
testApply
	self
		assert: (self mock apply: #())
		equals: 'mock()'.
	self
		assert: (self mock apply: #(1))
		equals: 'mock(1)'.
	self
		assert: (self mock apply: #(1 true))
		equals: 'mock(1,true)'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/13/2008 22:01'!
testAssign
	self
		assert: (self mock assign: 1)
		equals: 'mock=1'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:58'!
testAssignLocalTo
	self
		assert: (self mock assignLocalTo: 'x')
		equals: 'var x=mock'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:58'!
testAssignTo
	self
		assert: (self mock assignTo: 'x')
		equals: 'x=mock'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:58'!
testBinary
	self
		assert: (self mock & false)
		equals: 'mock&&false'.
	self
		assert: (self mock | 1)
		equals: 'mock||1'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:58'!
testCall
	self
		assert: (self mock call: 'foo')
		equals: 'mock.foo()'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/14/2008 09:38'!
testCallWith
	self
		assert: (self mock call: 'foo' with: 1)
		equals: 'mock.foo(1)'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/14/2008 09:39'!
testCallWithArguments
	self
		assert: (self mock call: 'foo' withArguments: #(1 2 3 4 5))
		equals: 'mock.foo(1,2,3,4,5)'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/14/2008 09:38'!
testCallWithWith
	self
		assert: (self mock call: 'foo' with: 1 with: 2)
		equals: 'mock.foo(1,2)'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/14/2008 09:39'!
testCallWithWithWith
	self
		assert: (self mock call: 'foo' with: 1 with: 2 with: 3)
		equals: 'mock.foo(1,2,3)'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/14/2008 12:22'!
testConcatenate
	self
		assert: (self mock , 2 , 3)
		equals: 'mock;2;3'.
	self
		assert: (self mock , nil , self mock)
		equals: 'mock;null;mock'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:58'!
testCondition
	self
		assert: (self mock condition: true)
		equals: 'if(true){mock}'.
	self
		assert: (self mock condition: false)
		equals: 'if(false){mock}'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:58'!
testConfirm
	self
		assert: (self mock confirm: 'Sure?')
		equals: 'if(confirm("Sure?")){mock}'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:58'!
testCreate
	self
		assert: self mock create
		equals: 'new mock'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/13/2008 22:01'!
testInterval
	self
		assert: (self mock interval: 2 seconds)
		equals: 'setInterval(function(){mock},2000)'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:58'!
testNot
	self
		assert: self mock not
		equals: '!!mock'.
	self
		assert: self mock not not
		equals: '!!!!mock'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:58'!
testProperty
	self
		assert: (self mock property: 'foo')
		equals: 'mock["foo"]'.
	self
		assert: (self mock property: 123)
		equals: 'mock[123]'.
	self
		assert: (self mock property: 'foo'; assign: 'bar')
		equals: 'mock["foo"]="bar"'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:58'!
testReturn
	self
		assert: (self mock return: 1)
		equals: 'mock;return 1'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:58'!
testThenElse
	| mock |
	mock := self mock.
	mock then: 1.
	self assert: mock equals: '(mock?1:null)'.

	mock := self mock.
	mock then: 1 else: 2.
	self assert: mock equals: '(mock?1:2)'! !

!JSDecorationTest methodsFor: 'testing' stamp: 'lr 10/13/2008 21:58'!
testTimeout
	| mock |
	mock := self mock.
	mock timeout: 123.
	self assert: mock equals: 'setTimeout(function(){mock},123)'! !

JSObjectTest subclass: #JSLoggingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Javascript-Tests-Core'!

!JSLoggingTest methodsFor: 'accessing' stamp: 'lr 10/13/2008 22:23'!
logger
	^ JSLogger on: self canvas! !

!JSLoggingTest methodsFor: 'testing' stamp: 'lr 10/13/2008 22:09'!
testAssert
	self 
		assert: (self logger assert: true)
		equals: 'console.assert(true)'.
	self
		assert: (self logger assertTrue: true)
		equals: 'console.assertTrue(true)'.
	self 
		assert: (self logger assertFalse: false)
		equals: 'console.assertFalse(false)'.
	self
		assert: (self logger assertNull: nil)
		equals: 'console.assertNull(null)'.
	self
		assert: (self logger assertNotNull: 1)
		equals: 'console.assertNotNull(1)'! !

!JSLoggingTest methodsFor: 'testing' stamp: 'lr 10/13/2008 22:06'!
testComparison
	self
		assert: (self logger assert: 1 equals: 1)
		equals: 'console.assertEquals(1,1)'.
	self
		assert: (self logger assert: 1 notEquals: 2)
		equals: 'console.assertNotEquals(1,2)'.
	self
		assert: (self logger assert: 1 greater: 2)
		equals: 'console.assertGreater(1,2)'.
	self
		assert: (self logger assert: 2 notGreater: 1)
		equals: 'console.assertNotGreater(2,1)'.
	self
		assert: (self logger assert: 2 less: 1)
		equals: 'console.assertLess(2,1)'.
	self
		assert: (self logger assert: 1 notLess: 2)
		equals: 'console.assertNotLess(1,2)'! !

!JSLoggingTest methodsFor: 'testing' stamp: 'lr 10/13/2008 22:06'!
testLogging
	self
		assert: (self logger log: 'done')
		equals: 'console.log("done")'.
	self
		assert: (self logger log: 'done %s and %s' format: #( 'this' 'that' ))
		equals: 'console.log("done %s and %s","this","that")'! !

!JSLoggingTest methodsFor: 'testing' stamp: 'lr 10/13/2008 22:06'!
testMessages
	self
		assert: (self logger debug: 3)
		equals: 'console.debug(3)'.
	self
		assert: (self logger info: 'eye m here 2')
		equals: 'console.info("eye m here 2")'.
	self
		assert: (self logger warn: 'don"t 4get ur grlfrnd')
		equals: 'console.warn("don\"t 4get ur grlfrnd")'.
	self
		assert: (self logger error: 'gone gone gone')
		equals: 'console.error("gone gone gone")'! !

!JSObjectTest methodsFor: 'utilities' stamp: 'lr 10/13/2008 21:47'!
assert: anObject equals: aString
	self
		assert: anObject asJavascript = aString
		description: anObject printString , ' expected to be ' , aString printString
		resumable: true! !

!JSObjectTest methodsFor: 'utilities' stamp: 'lr 10/13/2008 22:37'!
assert: aBlock renders: aString 
	| html |
	html := WARenderCanvas builder
		documentClass: JSDocument;
		callbackOwner: self;
		fullDocument: true;
		render: aBlock.
	self assert: html = aString! !

!JSObjectTest methodsFor: 'accessing' stamp: 'lr 10/13/2008 22:23'!
canvas
	^ WARenderCanvas context: WARenderingContext new! !

!JSObjectTest methodsFor: 'accessing' stamp: 'lr 10/13/2008 21:59'!
mock
	^ JSStream on: 'mock'! !

!JSObjectTest methodsFor: 'private' stamp: 'lr 10/13/2008 22:22'!
performTest
	| context |
	context := WARequestContext new.
	context server: (WAServer new
		codec: (SeasidePlatformSupport codecForEncoding: 'utf-8');
		yourself).
	WACurrentRequestContext 
		use: context
		during: [ super performTest ]! !

!JSObjectTest methodsFor: 'accessing' stamp: 'lr 10/13/2008 22:21'!
stream
	^ JSStream new! !

JSObjectTest subclass: #JSRenderingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Javascript-Tests-Core'!

!JSRenderingTest methodsFor: 'testing' stamp: 'lr 10/13/2008 22:29'!
testAddToEvent
	self 
		assert: [ :html | html div onClick: self mock ]
		renders: '<div onclick="mock"></div>'.
	self 
		assert: [ :html | html div onMouseOut: self mock ]
		renders: '<div onmouseout="mock"></div>'.
	self 
		assert: [ :html | html div onKeyUp: self mock ]
		renders: '<div onkeyup="mock"></div>'! !

!JSRenderingTest methodsFor: 'testing' stamp: 'lr 10/13/2008 22:30'!
testAddToScript
	self 
		assert: [ :html | html script: self mock ]
		renders: '<script type="text/javascript">/*<!![CDATA[*/mock/*]]>*/</script>'! !

JSObjectTest subclass: #JSScriptTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Javascript-Tests-Core'!

!JSScriptTest methodsFor: 'accessing' stamp: 'lr 10/13/2008 22:23'!
function
	^ JSFunction on: self canvas! !

!JSScriptTest methodsFor: 'accessing' stamp: 'lr 10/13/2008 22:23'!
script
	^ JSScript on: self canvas! !

!JSScriptTest methodsFor: 'testing' stamp: 'lr 10/13/2008 22:14'!
testConvert
	self
		assert: self function
		equals: 'function(){}'.
	self
		assert: self function asFunction
		equals: 'function(){}'.
	self 
		assert: 'alert("1")' asFunction
		equals: 'function(){alert("1")}'! !

!JSScriptTest methodsFor: 'testing-function' stamp: 'lr 10/13/2008 22:03'!
testFunctionArguments
	self
		assert: (self function arguments: #(a))
		equals: 'function(a){}'.
	self
		assert: (self function arguments: #(a b))
		equals: 'function(a,b){}'.
	self
		assert: (self function arguments: #(a b c))
		equals: 'function(a,b,c){}'! !

!JSScriptTest methodsFor: 'testing-function' stamp: 'lr 10/13/2008 22:03'!
testFunctionReturn
	| function |
	function := self function.
	function add: (self stream nextPutAll: 'foo').
	function add: (self stream nextPutAll: 'bar').
	function add: (self stream nextPutAll: 'baz').
	self assert: function equals: 'function(){foo;bar;baz}'.

	function := self function return: true.
	function add: (self stream nextPutAll: 'foo').
	function add: (self stream nextPutAll: 'bar').
	function add: (self stream nextPutAll: 'baz').
	self assert: function equals: 'function(){foo;bar;return baz}'! !

!JSScriptTest methodsFor: 'testing-script' stamp: 'lr 10/13/2008 22:11'!
testScriptAdd
	| script |
	script := self script.
	script add: (self stream nextPutAll: 'foo').
	self assert: script equals: 'foo'.
	script add: (self stream nextPutAll: 'bar').
	self assert: script equals: 'foo;bar'! !

!JSScriptTest methodsFor: 'testing-script' stamp: 'lr 10/13/2008 22:12'!
testScriptConcatenate
	| script |
	script := self stream nextPutAll: 'foo'.
	self assert: script equals: 'foo'.

	script := script , (self stream nextPutAll: 'bar').
	self assert: script equals: 'foo;bar'.

	script := script , (self stream nextPutAll: 'baz').
	self assert: script equals: 'foo;bar;baz'.

	script := script , (self script , (self stream nextPutAll: 'zork')).
	self assert: script equals: 'foo;bar;baz;zork'! !

!JSScriptTest methodsFor: 'testing-script' stamp: 'lr 10/13/2008 22:12'!
testScriptEmpty
	self assert: self script equals: ''! !

JSObjectTest subclass: #JSStreamTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Javascript-Tests-Core'!

!JSStreamTest methodsFor: 'testing' stamp: 'lr 10/13/2008 22:13'!
testArgument
	| stream |
	stream := self stream argument: 1.
	self assert: stream contents = '(1)'! !

!JSStreamTest methodsFor: 'testing' stamp: 'lr 10/13/2008 22:13'!
testArguments
	| stream |
	stream := self stream arguments: #(1 2 3).
	self assert: stream contents = '(1,2,3)'! !

!JSStreamTest methodsFor: 'testing' stamp: 'lr 10/13/2008 22:13'!
testCopy
	| stream1 stream2 |
	stream1 := self stream nextPutAll: 'foo'.
	stream2 := stream1 copy nextPutAll: 'bar'.
	stream1 nextPutAll: 'zork'.
	self assert: stream1 contents = 'foozork'.
	self assert: stream2 contents = 'foobar'! !

!JSStreamTest methodsFor: 'testing' stamp: 'lr 10/13/2008 22:13'!
testJavascript
	| stream |
	stream := self stream javascript: #(1 2).
	self assert: stream contents = '[1,2]'! !

!JSStreamTest methodsFor: 'testing' stamp: 'lr 10/13/2008 22:13'!
testNew
	self assert: (JSStream on: 'mock') equals: 'mock'! !

!JSStreamTest methodsFor: 'testing' stamp: 'lr 10/13/2008 22:13'!
testNextPut
	| stream |
	stream := self stream nextPut: $f.
	self assert: stream contents = 'f'! !

!JSStreamTest methodsFor: 'testing' stamp: 'lr 10/13/2008 22:13'!
testNextPutAll
	| stream |
	stream := self stream nextPutAll: 'foo'.
	self assert: stream contents = 'foo'! !
